@@ -5,13 +5,8 @@ use strict;
 use IO::Socket;
 use base qw( Net::IPMessenger::EventHandler );
 
-our $VERSION = '0.05';
-
 sub BR_ENTRY {
-    my $self  = shift;
-    my $ipmsg = shift;
-    my $user  = shift;
-
+    my( $self, $ipmsg, $user ) = @_;
     my $command = $ipmsg->messagecommand('ANSENTRY');
     $command->set_encrypt if $ipmsg->encrypt;
     $ipmsg->send(
@@ -23,9 +18,7 @@ sub BR_ENTRY {
 }
 
 sub ANSLIST {
-    my $self     = shift;
-    my $ipmsg    = shift;
-    my $user     = shift;
+    my( $self, $ipmsg, $user ) = @_;
     my $key      = $user->key;
     my $peeraddr = inet_ntoa( $ipmsg->socket->peeraddr );
 
@@ -34,10 +27,7 @@ sub ANSLIST {
 }
 
 sub SENDMSG {
-    my $self  = shift;
-    my $ipmsg = shift;
-    my $user  = shift;
-
+    my( $self, $ipmsg, $user ) = @_;
     my $command = $ipmsg->messagecommand( $user->command );
     if ( $command->get_sendcheck ) {
         $ipmsg->send(
@@ -51,17 +41,23 @@ sub SENDMSG {
     # decrypt message if the message is encrypted
     # and encryption support is available
     if ( $command->get_encrypt and $ipmsg->encrypt ) {
-        my $decrypted = $ipmsg->encrypt->decrypt_message( $user->get_message );
+        my $encrypt = $ipmsg->encrypt;
+        my $decrypted = $encrypt->decrypt_message( $user->get_message );
         $user->option($decrypted);
+        if ( $command->get_fileattach ) {
+            $user->attach( $encrypt->attach );
+        }
+    }
+    elsif ( $command->get_fileattach ) {
+        my( $option, $attach ) = split /\0/, $user->get_message;
+        $user->option($option);
+        $user->attach($attach);
     }
     push @{ $ipmsg->message }, $user;
 }
 
 sub RECVMSG {
-    my $self  = shift;
-    my $ipmsg = shift;
-    my $user  = shift;
-
+    my( $self, $ipmsg, $user ) = @_;
     my $option = $user->option;
     $option =~ s/\0//g;
     if ( exists $ipmsg->sending_packet->{$option} ) {
@@ -70,10 +66,7 @@ sub RECVMSG {
 }
 
 sub READMSG {
-    my $self  = shift;
-    my $ipmsg = shift;
-    my $user  = shift;
-
+    my( $self, $ipmsg, $user ) = @_;
     my $command = $ipmsg->messagecommand( $user->command );
     if ( $command->get_readcheck ) {
         $ipmsg->send(
@@ -86,10 +79,7 @@ sub READMSG {
 }
 
 sub GETINFO {
-    my $self  = shift;
-    my $ipmsg = shift;
-    my $user  = shift;
-
+    my( $self, $ipmsg, $user ) = @_;
     $ipmsg->send(
         {
             command => $ipmsg->messagecommand('SENDINFO'),
@@ -99,12 +89,8 @@ sub GETINFO {
 }
 
 sub GETPUBKEY {
-    my $self  = shift;
-    my $ipmsg = shift;
-    my $user  = shift;
-
+    my( $self, $ipmsg, $user ) = @_;
     return unless $ipmsg->encrypt;
-
     $ipmsg->send(
         {
             command => $ipmsg->messagecommand('ANSPUBKEY'),
@@ -114,12 +100,8 @@ sub GETPUBKEY {
 }
 
 sub ANSPUBKEY {
-    my $self  = shift;
-    my $ipmsg = shift;
-    my $user  = shift;
-
+    my( $self, $ipmsg, $user ) = @_;
     return unless $ipmsg->encrypt;
-
     my $key     = $user->key;
     my $message = $user->get_message;
     my( $option, $public_key ) = split /:/,  $message;
@@ -140,12 +122,6 @@ __END__
 
 Net::IPMessenger::RecvEventHandler - default event handler
 
-
-=head1 VERSION
-
-This document describes Net::IPMessenger::RecvEventHandler version 0.04
-
-
 =head1 SYNOPSIS
 
     use Net::IPMessenger::RecvEventHandler;
@@ -206,48 +182,3 @@ Gets RSA public key and store it.
 =head1 SEE ALSO
 
 L<Net::IPMessenger::EventHandler>
-
-
-=head1 BUGS AND LIMITATIONS
-
-Please report any bugs or feature requests to
-C<bug-net-ipmessenger@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
-
-=head1 AUTHOR
-
-Masanori Hara  C<< <massa.hara at gmail.com> >>
-
-
-=head1 LICENCE AND COPYRIGHT
-
-Copyright (c) 2007, Masanori Hara C<< <massa.hara at gmail.com> >>.
-All rights reserved.
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
-
-
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
